Function fcaptcha::util::get_timestamp
source · pub fn get_timestamp() -> Result<u64, SystemTimeError>Expand description
Get a timestamp in seconds since the Unix epoch.
pub fn get_timestamp() -> Result<u64, SystemTimeError>Get a timestamp in seconds since the Unix epoch.